@@ -21,7 +21,8 @@ using Cert = folly::AsyncTransportCertificate;
 
 /**
  * This class is a wrapper around AsyncTransportWrapper to handle most app level
- * interactions so that the derived client and server classes
+ * interactions. The derived client and server classes utilize the protected
+ * methods.
  */
 class AsyncFizzBase : public folly::WriteChainAsyncTransportWrapper<
                           folly::AsyncTransportWrapper>,
@@ -322,6 +323,14 @@ class AsyncFizzBase : public folly::WriteChainAsyncTransportWrapper<
     }
   }
 
+  /**
+   * If set, after AsyncFizzBase has been used to write `bytes` worth of data,
+   * AsyncFizzBase will automatically initiate a key_update
+   */
+  void setRekeyAfterWriting(size_t bytes) {
+    keyUpdateThreshold_ = bytes;
+  }
+
   /*
    * Gets the client random associated with this connection. The CR can be
    * used as a transport agnostic identifier (for instance, for NSS keylogging)
@@ -458,10 +467,26 @@ class AsyncFizzBase : public folly::WriteChainAsyncTransportWrapper<
     }
   }
 
+  /**
+   * Called by derived classes after an AppWrite of `bytesWritten` bytes is
+   * performed.
+   */
+  void wroteApplicationBytes(size_t bytesWritten) {
+    appByteProcessedUnderKey_ += bytesWritten;
+    if (keyUpdateThreshold_ &&
+        appByteProcessedUnderKey_ >= keyUpdateThreshold_) {
+      appByteProcessedUnderKey_ = 0;
+      initiateKeyUpdate(KeyUpdateRequest::update_not_requested);
+    }
+  }
+
   folly::IOBufQueue transportReadBuf_{folly::IOBufQueue::cacheChainLength()};
   Aead::AeadOptions readAeadOptions_;
   Aead::AeadOptions writeAeadOptions_;
 
+  size_t appByteProcessedUnderKey_{0};
+  size_t keyUpdateThreshold_{0};
+
  private:
   class QueuedWriteRequest
       : private folly::AsyncTransportWrapper::WriteCallback {
@@ -478,6 +503,8 @@ class AsyncFizzBase : public folly::WriteChainAsyncTransportWrapper<
 
     void unlinkFromBase();
 
+    void fail(const folly::AsyncSocketException&);
+
     size_t getEntireChainBytesBuffered() {
       DCHECK(!next_);
       return entireChainBytesBuffered;
@@ -558,6 +585,7 @@ class AsyncFizzBase : public folly::WriteChainAsyncTransportWrapper<
   size_t readSizeHint_{0};
 
   QueuedWriteRequest* tailWriteRequest_{nullptr};
+  QueuedWriteRequest* immediatelyPendingWriteRequest_{nullptr};
 
   HandshakeTimeout handshakeTimeout_;
 
