@@ -91,7 +91,7 @@ bool isValidPublicName(const std::string& publicName) {
   }
 
   std::vector<std::string> parts;
-  folly::split(".", publicName, parts, false);
+  folly::split('.', publicName, parts, false);
 
   // Check that each part is a valid LDH label ([a-z,A-Z,0-9,-])
   for (auto& part : parts) {
@@ -489,7 +489,8 @@ size_t calculateECHPadding(
   auto sni = getExtension<ServerNameList>(chlo.extensions);
   if (sni) {
     // Add max(0, maxLen - len(server_name))
-    size_t sniLen = sni->server_name_list[0].hostname->computeChainDataLength();
+    size_t sniLen =
+        sni->server_name_list.at(0).hostname->computeChainDataLength();
     if (sniLen < maxLen) {
       padding = maxLen - sniLen;
     }
